pub(crate) fn estimate_render_task_cost(
task: &RenderTaskType,
paths: &[PathEl],
) -> f32Expand description
Try to estimate the cost of the render task.
pub(crate) fn estimate_render_task_cost(
task: &RenderTaskType,
paths: &[PathEl],
) -> f32Try to estimate the cost of the render task.